@@ -22,6 +22,7 @@ class MetaDataType(TypedDict, total=False):
     unit: str
     states: Dict[int, str]
     ccSpecific: Dict[str, Any]
+    allowManualEntry: bool
 
 
 class ValueDataType(TypedDict, total=False):
@@ -126,6 +127,11 @@ class ValueMetadata:
         """Return ccSpecific."""
         return self.data.get("ccSpecific", {})
 
+    @property
+    def allow_manual_entry(self) -> Optional[bool]:
+        """Return allowManualEntry."""
+        return self.data.get("allowManualEntry")
+
     def update(self, data: MetaDataType) -> None:
         """Update data."""
         self.data.update(data)
@@ -233,8 +239,10 @@ class Value:
         if "metadata" in data:
             self._metadata.update(data["metadata"])
 
-        # handle buffer dict and json string in value
-        if self.metadata.type == "string":
+        # Handle buffer dict and json string in value.
+        # In schema version 1 this is type string,
+        # while in schema version 2 this is type buffer.
+        if self.metadata.type in ("string", "buffer"):
             if isinstance(self._value, dict):
                 self._value = parse_buffer(self._value)
             elif is_json_string(self._value):
@@ -243,7 +251,7 @@ class Value:
 
 class ValueNotification(Value):
     """
-    Model for a Value Nofification message.
+    Model for a Value Notification message.
 
     https://zwave-js.github.io/node-zwave-js/#/api/node?id=quotvalue-notificationquot
     """
@@ -258,6 +266,11 @@ class ConfigurationValue(Value):
     def configuration_value_type(self) -> ConfigurationValueType:
         """Return configuration value type."""
         if self.metadata.type == "number":
+            if (
+                self.metadata.allow_manual_entry
+                and not self.metadata.max == self.metadata.min == 0
+            ):
+                return ConfigurationValueType.MANUAL_ENTRY
             if self.metadata.states:
                 return ConfigurationValueType.ENUMERATED
             if (
